#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Utilities
"""


class Ex(Exception):
    """Exception wrapping all exceptions of this package"""

    pass
